<!-- team 团队 -->
<template>
  <div
    class="full-page"
    element-loading-text="数据加载中..."
    element-loading-spinner="el-icon-loading"
    element-loading-background="rgba(255,255,255, 0.5)"
    v-loading.fullscreen.lock="markLoading"
  >
    <el-form :inline="true" :model="parameter">
      <el-row>
        <el-col :span="4">
          <el-form-item style="width: 100%">
            <el-input clearable v-model="querys[0].value" placeholder="请输入团队"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="4">
          <el-form-item style="width: 100%">
            <el-input clearable v-model="querys[1].value" placeholder="请输入负责人"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="2">
          <el-button type="primary" @click="getData(1)" icon="el-icon-search">查询</el-button>
        </el-col>
      </el-row>
    </el-form>
    <div style="margin-bottom: 10px" ref="btnPanel">
      <el-button
        icon="el-icon-plus"
        type="primary"
        class="btn btn-plus"
        @click="handleAdd"
        v-methodauth="'TeamFilingManage_add'"
      >添加</el-button>
      <el-button
        slot="reference"
        icon="el-icon-delete"
        type="danger"
        class="btn btn-delete"
        @click="handleDelete"
        v-methodauth="'TeamFilingManage_delete'"
        :disabled="deleteIds ? false : true"
      >删除</el-button>
    </div>
    <div class="table-wrapper">
      <el-table
        height="100%"
        row-key="id"
        align="center"
        :data="tableData"
        :cell-style="{ 'text-align': 'center' }"
        style="min-width: 100%; overflow: auto"
        :header-cell-style="{ 'text-align': 'center' }"
        v-loading="loading"
        @selection-change="handleSelectionChange"
        ref="table"
      >
        <el-table-column type="selection" width="55" align="center" :selectable="selectable"></el-table-column>
        <el-table-column type="index" width="60" label="序号"></el-table-column>
        <el-table-column prop="disposedObjectName" label="团队名称"></el-table-column>
        <el-table-column prop="teamSize" label="规模"></el-table-column>
        <el-table-column prop="count" label="事件频次"></el-table-column>
        <el-table-column prop="headman" label="负责人"></el-table-column>
        <el-table-column prop="phone" label="联系电话"></el-table-column>
        <!-- <el-table-column prop="detailAddress" label="归属管理地"></el-table-column> -->
        <!-- <el-table-column prop="createTime" label="添加时间"></el-table-column> -->
        <el-table-column width="100" label="操作">
          <template v-slot="{ row }">
            <el-link
              type="danger"
              :underline="false"
              class="cloumn-btn"
              @click="handleDelete('delete', row)"
              v-methodauth="'TeamFilingManage_delete'"
            >删除</el-link>
          </template>
        </el-table-column>
      </el-table>
    </div>
    <pagination
      ref="paginationPanel"
      style="margin-top: 10px"
      :pageResult="pageResult"
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
    />
    <team-dialog ref="formDialog" @getData="getData"></team-dialog>
  </div>
</template>
<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import TeamDialog from './TeamDialog.vue'
import BlacklistManage from '@/api/FeedbackArchiving/BlacklistManage.js'

export default {
    name: 'Team',
    components: {
        pagination,
        TeamDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            tableMaxHeight: 400,
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'name',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'headman',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'type',
                    relation: 'AND',
                    value: '2'
                }
            ],
            reqData: {
                querys: [],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true
                }
            },
            tableLoading: false,
            deleteIds: '',
            parameter: {
                size: 20,
                page: 1
            }
        }
    },
    created() {
        // this.fljbList = dictUtils.getDictItemsFromCache('fljb')

        this.getData()
    },
    methods: {
        selectable(row) {
            if (row.isDele === '1') {
                return false
            } else {
                return true
            }
        },
        //获取数据
        getData(page) {
            if (page) {
                this.reqData.pageBean.page = page
            }
            this.reqData.querys = []
            if (this.querys[0].value) {
                this.reqData.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.reqData.querys.push(this.querys[1])
            }
            if (this.querys[2].value) {
                this.reqData.querys.push(this.querys[2])
            }
            this.tableLoading = true
            BlacklistManage.blackListQuery(this.reqData, res => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
                // this.tableData.forEach(e => {
                //     this.fljbList.forEach(f => {
                //         if (e.level == f.value) {
                //             e.levelName = f.name
                //         }
                //     })
                // })
            })
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map(item => item.id)
            this.deleteIds = arr.join(',')
            console.log(this.deleteIds)
        },
        //删除
        handleDelete(type, val) {
            console.log(val)
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'warning'
            }).then(() => {
                this.markLoading = true
                if (type === 'delete') {
                    BlacklistManage.blackListDetele([val.id], res => {
                        if (res.state) {
                            this.getData()
                            this.$message.success('删除成功')
                            this.markLoading = false
                        } else {
                            this.markLoading = false
                        }
                    })
                } else {
                    BlacklistManage.blackListDetele(this.deleteIds, res => {
                        if (res.state) {
                            this.getData()
                            this.$message.success('删除成功')
                            this.markLoading = false
                        } else {
                            this.markLoading = false
                        }
                    })
                }
            })
        },
        handleSizeChange(val) {
            this.reqData.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.reqData.pageBean.page = val
            this.getData()
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        }
    }
}
</script>
<style lang='scss' scoped>
@import '~@/assets/css/element-variables.scss';
@import '~@/assets/css/common.scss';

.table-wrapper {
    height: calc(100% - 170px);
}
</style>
